documentFactory.BaseDocumentFactory

|  | ## Cheshire3 Object Model: Class BaseDocumentFactory

Module documentFactory :: Class BaseDocumentFactory

## Class BaseDocumentFactory
source code

Object Tree:

                 object --+
                          |
      configParser.C3Object --+
                              |
    baseObjects.DocumentFactory --+
                                  |
                                 BaseDocumentFactory

Known Subclasses:
  ComponentDocumentFactory, postgres.PostgresDocumentFactory

Instance Methods

__init__(self, session, config, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
__iter__(self)
get_document(self, session=None, idx=-1)
load(self, session, data=None, cache=None, format=None, schema=None, codec=None)
next(self)
register_stream(self, format, cls)
Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

cache |
codec |
dataPath |
docStream |
format |
generator |
previousIdx |
schema |
streamHash |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### __iter__(self) | source code

### get_document(self, session=None, idx=-1) | source code
Overrides: baseObjects.DocumentFactory.get_document

### load(self, session, data=None, cache=None, format=None, schema=None, codec=None) | source code
Overrides: baseObjects.DocumentFactory.load

### next(self) | source code

### register_stream(self, format, cls) | source code

Class Variable Details

    ### cache Value:
        0

    ### codec Value:
        ''

    ### dataPath Value:
        ''

    ### docStream Value:
        None

    ### format Value:
        ''

    ### generator Value:
        None

    ### previousIdx Value:
        -1

    ### schema Value:
        ''

    ### streamHash Value:
        {}